@@ -31,19 +31,21 @@ async def get_a_req_async(url ,
                           headers = cte.headers ,
                           params = None ,
                           verify_ssl = True ,
-                          timeout = None) :
+                          timeout = None ,
+                          proxies = None) :
     async with ClientSession() as s :
         try :
             r = await s.get(url ,
                             headers = headers ,
                             params = params ,
                             verify_ssl = verify_ssl ,
-                            timeout = timeout)
+                            timeout = timeout ,
+                            proxy_headers = proxies , )
             return RGetReqAsync(status = r.status ,
                                 headers = r.headers ,
                                 cont = await r.read())
-        except (
-        ClientConnectorError , ClientPayloadError , ClientOSError) as e :
+        except (ClientConnectorError , ClientPayloadError ,
+                ClientOSError) as e :
             print(e)
             return RGetReqAsync(err = e)
 
@@ -78,3 +80,6 @@ async def get_jsons_async(urls , content_type = None , **kwargs) :
     fu = partial(get_a_req_async , **kwargs)
     rs = await fu(urls)
     return [await rs.json(content_type = content_type) for rs in rs]
+
+def get_jsons_async_sync(urls , content_type = None , **kwargs) :
+    return asyncio.run(get_jsons_async(urls , content_type , **kwargs))
