@@ -6,6 +6,9 @@ import json
 
 
 def read_file(fp , mode = 'r' , encoding = 'utf-8') :
+    if mode == 'rb' :
+        with open(fp , mode) as f :
+            return f.read()
     with open(fp , mode , encoding = encoding) as f :
         return f.read()
 
