@@ -16,7 +16,6 @@ from requests_html import AsyncHTMLSession
 from requests_html import HTMLSession
 
 from .const import Const
-from .files import write_txt_to_file
 from .files import write_txt_to_file_async
 
 
@@ -42,12 +41,12 @@ class RGetAndRender :
     html: (str , None) = None
     err: (str , None) = None
 
-async def get_and_render_by_requests_html_async(url ,
-                                                headers = cte.headers ,
-                                                params = None ,
-                                                verify = True ,
-                                                get_timeout = None ,
-                                                render_timeout = None) :
+async def get_a_req_and_render_by_requests_html_async(url ,
+                                                      headers = cte.headers ,
+                                                      params = None ,
+                                                      verify = True ,
+                                                      get_timeout = None ,
+                                                      render_timeout = None) :
     r = await ases.get(url ,
                        headers = headers ,
                        params = params ,
@@ -66,8 +65,12 @@ async def get_and_render_by_requests_html_async(url ,
                              html = None ,
                              err = e)
 
+def get_a_req_and_render_by_requests_html(url , **kwargs) :
+    fu = get_a_req_and_render_by_requests_html_async(url , **kwargs)
+    return asyncio.run(fu)
+
 async def get_a_rendered_html_and_save_async(url , fp , **kwargs) :
-    fu = partial(get_and_render_by_requests_html_async , **kwargs)
+    fu = partial(get_a_req_and_render_by_requests_html_async , **kwargs)
     o = await fu(url)
     outer_html = o.html
     if outer_html :
@@ -79,50 +82,5 @@ async def get_rendered_htmls_and_save_async(urls , fps , **kwargs) :
     co_tasks = [fu(x , y) for x , y in zip(urls , fps)]
     return await asyncio.gather(*co_tasks)
 
-def get_and_render_by_requests_html(url ,
-                                    headers = cte.headers ,
-                                    params = None ,
-                                    verify = True ,
-                                    get_timeout = None ,
-                                    render_timeout = None) :
-    """ makes a get request & renders it javascript """
-
-    hs = HTMLSession()
-    r = hs.get(url ,
-               headers = headers ,
-               params = params ,
-               verify = verify ,
-               timeout = get_timeout)
-    hs.close()
-
-    try :
-        r.html.render(timeout = render_timeout)
-        return RGetAndRender(status = r.status_code ,
-                             headers = r.headers ,
-                             html = r.html.html ,
-                             err = None)
-
-    except (XMLSyntaxError , tout , PageError , ConnectionError) as e :
-        print(e)
-        return RGetAndRender(status = r.status_code ,
-                             headers = r.headers ,
-                             html = None ,
-                             err = e)
-
-def get_a_rendered_html_and_save(url ,
-                                 fp ,
-                                 headers = cte.headers ,
-                                 params = None ,
-                                 verify = True ,
-                                 get_timeout = None ,
-                                 render_timeout = None) :
-    o = get_and_render_by_requests_html(url ,
-                                        headers = headers ,
-                                        params = params ,
-                                        verify = verify ,
-                                        get_timeout = get_timeout ,
-                                        render_timeout = render_timeout)
-    outer_html = o.html
-    if outer_html :
-        write_txt_to_file(outer_html , fp)
-    return o
+def get_rendered_htmls_and_save_async_sync(urls , fps , **kwargs) :
+    return asyncio.run(get_rendered_htmls_and_save_async(urls , fps , **kwargs))
